#
# spec file for package perl-Data-ObjectDriver
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Data-ObjectDriver
Name:           perl-Data-ObjectDriver
Version:        0.250.0
Release:        1.1
# 0.25 -> normalize -> 0.250.0
%define cpan_version 0.25
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Simple, transparent data interface, with caching
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/S/SI/SIXAPART/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Class::Accessor::Fast)
BuildRequires:  perl(Class::Data::Inheritable)
BuildRequires:  perl(Class::Trigger)
BuildRequires:  perl(DBI)
BuildRequires:  perl(ExtUtils::MakeMaker) >= 6.59
BuildRequires:  perl(Module::Build)
BuildRequires:  perl(Module::Build::Tiny) >= 0.35.0
BuildRequires:  perl(Test::Exception)
BuildRequires:  perl(version)
Requires:       perl(Class::Accessor::Fast)
Requires:       perl(Class::Data::Inheritable)
Requires:       perl(Class::Trigger)
Requires:       perl(DBI)
Provides:       perl(Data::ObjectDriver) = %{version}
Provides:       perl(Data::ObjectDriver::BaseObject)
Provides:       perl(Data::ObjectDriver::BaseView)
Provides:       perl(Data::ObjectDriver::Driver::BaseCache)
Provides:       perl(Data::ObjectDriver::Driver::Cache::Apache)
Provides:       perl(Data::ObjectDriver::Driver::Cache::Cache)
Provides:       perl(Data::ObjectDriver::Driver::Cache::Memcached)
Provides:       perl(Data::ObjectDriver::Driver::Cache::RAM)
Provides:       perl(Data::ObjectDriver::Driver::DBD)
Provides:       perl(Data::ObjectDriver::Driver::DBD::MariaDB)
Provides:       perl(Data::ObjectDriver::Driver::DBD::Oracle)
Provides:       perl(Data::ObjectDriver::Driver::DBD::Oracle::db)
Provides:       perl(Data::ObjectDriver::Driver::DBD::Pg)
Provides:       perl(Data::ObjectDriver::Driver::DBD::SQLite)
Provides:       perl(Data::ObjectDriver::Driver::DBD::mysql)
Provides:       perl(Data::ObjectDriver::Driver::DBI)
Provides:       perl(Data::ObjectDriver::Driver::GearmanDBI)
Provides:       perl(Data::ObjectDriver::Driver::MultiPartition)
Provides:       perl(Data::ObjectDriver::Driver::Multiplexer)
Provides:       perl(Data::ObjectDriver::Driver::Partition)
Provides:       perl(Data::ObjectDriver::Driver::SimplePartition)
Provides:       perl(Data::ObjectDriver::Errors)
Provides:       perl(Data::ObjectDriver::Iterator)
Provides:       perl(Data::ObjectDriver::Profiler)
Provides:       perl(Data::ObjectDriver::ResultSet)
Provides:       perl(Data::ObjectDriver::SQL)
Provides:       perl(Data::ObjectDriver::SQL::Oracle)
%undefine       __perllib_provides
Recommends:     perl(Text::SimpleTable)
%{perl_requires}

%description
_Data::ObjectDriver_ is an object relational mapper, meaning that it maps
object-oriented design concepts onto a relational database.

It's inspired by, and descended from, the _MT::ObjectDriver_ classes in Six
Apart's Movable Type and TypePad weblogging products. But it adds in
caching and partitioning layers, allowing you to spread data across
multiple physical databases, without your application code needing to know
where the data is stored.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version} -p1

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Build.PL --installdirs=vendor
./Build build --flags=%{?_smp_mflags}

%check
./Build test

%install
./Build install --destdir=%{buildroot} --create_packlist=0
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README.md ToDo
%license LICENSE

%changelog
* Tue Apr 15 2025 Tina Müller <timueller+perl@suse.de>
- updated to 0.250.0 (0.25)
  see /usr/share/doc/packages/perl-Data-ObjectDriver/Changes
* Thu Oct 24 2024 Tina Müller <timueller+perl@suse.de>
- updated to 0.230.0 (0.23)
  see /usr/share/doc/packages/perl-Data-ObjectDriver/Changes
* Thu Feb  2 2023 Tina Müller <timueller+perl@suse.de>
- updated to 0.22
  see /usr/share/doc/packages/perl-Data-ObjectDriver/Changes
* Fri Oct 30 2020 Tina Müller <timueller+perl@suse.de>
- updated to 0.21
  see /usr/share/doc/packages/perl-Data-ObjectDriver/Changes
* Tue Sep 15 2020 Tina Müller <timueller+perl@suse.de>
- updated to 0.20
  see /usr/share/doc/packages/perl-Data-ObjectDriver/Changes
* Wed Mar  4 2020 <timueller+perl@suse.de>
- updated to 0.19
  see /usr/share/doc/packages/perl-Data-ObjectDriver/Changes
* Tue Jul 16 2019 Stephan Kulow <coolo@suse.com>
- updated to 0.18
  see /usr/share/doc/packages/perl-Data-ObjectDriver/Changes
* Wed Mar 13 2019 Stephan Kulow <coolo@suse.com>
- updated to 0.17
  see /usr/share/doc/packages/perl-Data-ObjectDriver/Changes
* Thu Apr 20 2017 coolo@suse.com
- updated to 0.15
  see /usr/share/doc/packages/perl-Data-ObjectDriver/Changes
  0.15 2017-04-19T01:21:41Z
  - Fix failed tests with Perl 5.25.11 (miniuchi) #24
* Wed Jan 20 2016 coolo@suse.com
- updated to 0.14
  see /usr/share/doc/packages/perl-Data-ObjectDriver/Changes
  0.14 2016-01-14T03:03:02Z
  - Fix test for SQLite 3.10 compatibility (ziguzagu) #21
* Wed May 20 2015 coolo@suse.com
- updated to 0.13
  see /usr/share/doc/packages/perl-Data-ObjectDriver/Changes
  0.13 2015-05-20T02:26:46Z
  - Fix 0.12 changes with braking inserting new records (masiuchi) #20
* Mon May 18 2015 coolo@suse.com
- updated to 0.12
  see /usr/share/doc/packages/perl-Data-ObjectDriver/Changes
* Mon Apr 13 2015 coolo@suse.com
- updated to 0.11
  see /usr/share/doc/packages/perl-Data-ObjectDriver/Changes
* Mon Apr 13 2015 coolo@suse.com
- updated to 0.09
  see /usr/share/doc/packages/perl-Data-ObjectDriver/Changes
  0.09 2011.03.17
  - Fix reuse_dbh behaviour when ping fails on driver->dbh (RT 65448)
  0.08 2010.12.06
  - Fixed issue where a profiler cannot be returned if $@ is set
    https://github.com/sixapart/data-objectdriver/pull/1 (Akira Sawada)
  - Adds a new restricted IO operation mode controlled by the
    $Data::ObjectDriver::RESTRICT_IO flag (Brad Whitaker)
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Fri Nov  6 2009 dmueller@suse.de
- Initial package (0.06)
